# simpler import as described in the readme
from restcountries.base import RestCountryApiV2

__version__ = "2.0.0"
